@@ -2,13 +2,13 @@
 //
 // SPDX-License-Identifier: GPL-3.0-only
 
-use crate::grammar::symbol::Symbol;
+use crate::grammar::Symbol;
 
 use std;
 
 #[derive(Clone, Eq, Hash, PartialEq)]
 pub struct Production {
-    pub terms: Vec<Symbol>,
+    pub symbols: Vec<Symbol>,
 }
 
 impl std::fmt::Display for Production {
@@ -16,7 +16,7 @@ impl std::fmt::Display for Production {
         write!(
             f,
             "{}",
-            self.terms
+            self.symbols
                 .iter()
                 .map(Symbol::to_string)
                 .collect::<Vec<String>>()
