@@ -2,19 +2,23 @@
 //
 // SPDX-License-Identifier: GPL-3.0-only
 
-pub mod lexeme;
-pub mod lexer_builder;
-pub mod lexer_rule;
-pub mod position;
+//! Convert an input of characters into strings with an assigned meaning
 
-use self::lexeme::Lexeme;
-use self::lexer_rule::LexerRule;
-use self::position::Position;
+mod lexeme;
+mod lexer_builder;
+mod lexer_rule;
+mod position;
+
+pub use lexeme::Lexeme;
+pub use lexer_builder::LexerBuilder;
+pub use lexer_rule::LexerRule;
+pub use position::Position;
 use std::collections::LinkedList;
 
 pub struct Lexer<'a> {
     input:             &'a str,
     current_match_len: usize,
+    current_rule_name: &'a str,
     position:          Position,
     states_stack:      LinkedList<&'a str>,
 }
@@ -26,7 +30,7 @@ pub enum NextLexeme {
 }
 
 impl<'a> Lexer<'a> {
-    fn next_lexeme(&mut self, rules: &[LexerRule]) -> NextLexeme {
+    fn next_lexeme(&mut self, rules: &'a [LexerRule]) -> NextLexeme {
         if self.position.index < self.input.len() {
             let mut matches_: LinkedList<(usize, usize)> = LinkedList::new();
             let input = &self.input[self.position.index..];
@@ -46,13 +50,21 @@ impl<'a> Lexer<'a> {
                 panic!("Unable to lex input with the provided rules: {input}");
             }
 
-            let (len, rule_index) = matches_
+            // Pick matches with the same maximum length
+            // And take the first rule declared
+            let max_len = matches_
+                .iter()
+                .max_by(|left, right| left.0.cmp(&right.0))
+                .unwrap()
+                .0;
+            let (len, rule_index): (usize, usize) = matches_
                 .into_iter()
-                .rev()
-                .max_by(|(left, _), (right, _)| left.cmp(right))
+                .filter(|match_| match_.0 == max_len)
+                .min_by(|left, right| left.1.cmp(&right.1))
                 .unwrap();
 
             self.current_match_len = len;
+            self.current_rule_name = &rules[rule_index].name;
 
             rules[rule_index].action.clone()(self)
         } else {
@@ -65,19 +77,15 @@ impl<'a> Lexer<'a> {
             [self.position.index..self.position.index + self.current_match_len]
     }
 
-    pub fn take(&mut self, kind: &str) -> NextLexeme {
-        self.take_and_map(kind, |matched| matched.to_string())
+    pub fn take(&mut self) -> NextLexeme {
+        self.take_and_map(|matched| matched.to_string())
     }
 
-    pub fn take_and_map(
-        &mut self,
-        kind: &str,
-        function: fn(&str) -> String,
-    ) -> NextLexeme {
+    pub fn take_and_map(&mut self, function: fn(&str) -> String) -> NextLexeme {
         let matched = self.matched().to_string();
         self.position.consume(&matched);
 
-        let kind = kind.to_string();
+        let kind = self.current_rule_name.to_string();
         let raw = function(&matched);
 
         NextLexeme::Lexeme((kind, raw))
@@ -90,18 +98,17 @@ impl<'a> Lexer<'a> {
         NextLexeme::Skip
     }
 
-    pub fn take_and_retry(&mut self, kind: &str) -> NextLexeme {
-        self.take_and_map_and_retry(kind, |matched| matched.to_string())
+    pub fn take_and_retry(&mut self) -> NextLexeme {
+        self.take_and_map_and_retry(|matched| matched.to_string())
     }
 
     pub fn take_and_map_and_retry(
         &mut self,
-        kind: &str,
         function: fn(&str) -> String,
     ) -> NextLexeme {
         let matched = self.matched().to_string();
 
-        let kind = kind.to_string();
+        let kind = self.current_rule_name.to_string();
         let raw = function(&matched);
 
         NextLexeme::Lexeme((kind, raw))
@@ -125,11 +132,13 @@ impl<'a> Lexer<'a> {
 
     pub fn error(&mut self, msg: &str) -> NextLexeme {
         panic!(
-            "While lexing input: {:?}\nWith states: {:?}\nAt position: {}\n{}",
+            "\n\n{}\nWhile lexing input: {:?}\nAt rule: {}\nAt position: \
+             {}\nWith states stack: {:?}\n\n",
+            msg,
             self.matched().chars().collect::<Vec<char>>(),
-            self.states_stack,
+            self.current_rule_name,
             self.position,
-            msg
+            self.states_stack,
         );
     }
 }
@@ -138,6 +147,7 @@ pub fn lex(rules: &[LexerRule], input: &str) -> Vec<Lexeme> {
     let mut lexer = Lexer {
         input,
         current_match_len: 0,
+        current_rule_name: "",
         position: Position::new(),
         states_stack: LinkedList::new(),
     };
