@@ -2,12 +2,12 @@
 //
 // SPDX-License-Identifier: GPL-3.0-only
 
-use crate::grammar::rule::Rule;
-use crate::grammar::symbol::Symbol;
-use crate::lexer::lexeme::Lexeme;
+use crate::grammar::GrammarRule;
+use crate::grammar::Symbol;
+use crate::lexer::Lexeme;
 
-use crate::parser::column::Column;
-use crate::parser::state::State;
+use crate::parser::ParserColumn;
+use crate::parser::ParserState;
 
 #[derive(Clone, Debug, Hash)]
 pub enum Forest {
@@ -65,10 +65,10 @@ impl std::fmt::Display for Forest {
 }
 
 pub(crate) fn build_forest(
-    rules: &[Rule],
+    rules: &[GrammarRule],
     lexemes: &[Lexeme],
-    columns: &[Column],
-    state: &State,
+    columns: &[ParserColumn],
+    state: &ParserState,
 ) -> Vec<Forest> {
     build_forest_helper(
         rules,
@@ -76,18 +76,18 @@ pub(crate) fn build_forest(
         columns,
         vec![],
         state,
-        state.production.terms.len().overflowing_sub(1).0,
+        state.production.symbols.len().overflowing_sub(1).0,
         state.end_column,
     )
 }
 
 fn build_forest_helper(
-    rules: &[Rule],
+    rules: &[GrammarRule],
     lexemes: &[Lexeme],
-    columns: &[Column],
+    columns: &[ParserColumn],
 
     leaves: Vec<Forest>,
-    state: &State,
+    state: &ParserState,
     symbol_index: usize,
     end_column: usize,
 ) -> Vec<Forest> {
@@ -96,7 +96,7 @@ fn build_forest_helper(
     }
 
     let mut forests = Vec::new();
-    match &state.production.terms[symbol_index] {
+    match &state.production.symbols[symbol_index] {
         Symbol::Lexeme(_) => {
             let lexeme = &lexemes[end_column - 1];
             let mut leaves = leaves;
